@@ -1,4 +1,5 @@
 from institution import Institution
 from account import Account, BrokerageAccount, CreditCardAccount, BankAccount
-from request import Builder
+from client import Client
+from config import OfxConfig
 from version import __version__
